# Copyright (c) 2013, University of Bristol and University of Southampton.

from EStat.Templating import Template

class TemplateTake(Template):
    'Recodes values of a variable within a specified range to another value (chosen by user) and stores the resulting dataset in temporary memory. E.g. re-coding values within range 2 to 3 to new value 4: column (1,2,1,3,2.5,1.5) becomes (1,4,1,4,4,1.5).'

    __version__ = '1.0.0'

    tags = [ 'Data manipulation' ]
    engines = ['Python_script']

    inputs = '''
incols = DataMatrix('Input columns: ')
LID = DataVector('Level Identifier')
outdata = Text('Name of output dataset: ')
'''

    pythonscript = '''
import numpy
import numexpr

import EStat
from EStat.Templating import *
from EStat.DTAFile import DTAFile

ID = datafile.variables[LID]['data']
u, indices = numpy.unique(ID, return_index=True)

retval = DTAFile()
retval.nobs = len(u)
retval.addvariable(LID, data = u)

for i in range(0, len(incols)):
    retval.addvariable(incols[i], data = datafile.variables[incols[i]]['data'][indices])
    retval.variables[incols[i]]['format'] = datafile.variables[incols[i]]['format']
    retval.variables[incols[i]]['label'] = datafile.variables[incols[i]]['label']
    retval.variables[incols[i]]['varlabel'] = datafile.variables[incols[i]]['varlabel']
    retval.variables[incols[i]]['chars'] = datafile.variables[incols[i]]['chars']
    if incols[i] in datafile.valuelabels.keys():
        retval.valuelabels[incols[i]] = datafile.valuelabels[incols[i]]


outputs[str(outdata)] = retval
'''
